==> applet-service-1.0.2-20190124.082856-16-sources.jar: com/bizvane/appletservice/models/vo/ActivityRedPacketVo.java <==
package com.bizvane.appletservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityRedPacketPO;

import java.util.List;

public class ActivityRedPacketVo {
    //主表
    private MktActivityPOWithBLOBs activityPO;
    //奖励
    private MktActivityRedPacketPO activityRedPacketPO;

    private List<SysStorePo> storeList;

    private CouponDefinitionPO couponDefinitionPO;

    private String wxNickname;

    private String wxHeadUrl;
    //拆红包状态
    private Integer openRedEnvel;
    //助力状态
    private Integer assistanceRedEnvel;
    //发起状态
    private Integer launchRedEnvel;
    private Integer orgGrede;


    public MktActivityPOWithBLOBs getActivityPO() {
        return activityPO;
    }

    public void setActivityPO(MktActivityPOWithBLOBs activityPO) {
        this.activityPO = activityPO;
    }

    public MktActivityRedPacketPO getActivityRedPacketPO() {
        return activityRedPacketPO;
    }

    public void setActivityRedPacketPO(MktActivityRedPacketPO activityRedPacketPO) {
        this.activityRedPacketPO = activityRedPacketPO;
    }

    public List<SysStorePo> getStoreList() {
        return storeList;
    }

    public void setStoreList(List<SysStorePo> storeList) {
        this.storeList = storeList;
    }

    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public String getWxNickname() {
        return wxNickname;
    }

    public void setWxNickname(String wxNickname) {
        this.wxNickname = wxNickname;
    }

    public String getWxHeadUrl() {
        return wxHeadUrl;
    }

    public void setWxHeadUrl(String wxHeadUrl) {
        this.wxHeadUrl = wxHeadUrl;
    }

    public Integer getOpenRedEnvel() {
        return openRedEnvel;
    }

    public void setOpenRedEnvel(Integer openRedEnvel) {
        this.openRedEnvel = openRedEnvel;
    }

    public Integer getAssistanceRedEnvel() {
        return assistanceRedEnvel;
    }

    public void setAssistanceRedEnvel(Integer assistanceRedEnvel) {
        this.assistanceRedEnvel = assistanceRedEnvel;
    }

    public Integer getLaunchRedEnvel() {
        return launchRedEnvel;
    }

    public void setLaunchRedEnvel(Integer launchRedEnvel) {
        this.launchRedEnvel = launchRedEnvel;
    }

    public Integer getOrgGrede() {
        return orgGrede;
    }

    public void setOrgGrede(Integer orgGrede) {
        this.orgGrede = orgGrede;
    }

}

==> applet-service-1.0.2-20190424.103239-25-sources.jar: com/bizvane/appletservice/models/vo/ActivityRedPacketVo.java <==
package com.bizvane.appletservice.models.vo;

import com.bizvane.centerstageservice.models.po.SysStorePo;
import com.bizvane.couponfacade.models.po.CouponDefinitionPO;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityRedPacketPO;

import java.util.List;

public class ActivityRedPacketVo {
    //主表
    private MktActivityPOWithBLOBs activityPO;
    //奖励
    private MktActivityRedPacketPO activityRedPacketPO;

    private List<SysStorePo> storeList;

    private CouponDefinitionPO couponDefinitionPO;

    private String wxNickname;

    private String wxHeadUrl;
    //拆红包状态
    private Integer openRedEnvel;
    //助力状态
    private Integer assistanceRedEnvel;
    //发起状态
    private Integer launchRedEnvel;
    private Integer orgGrede;
    private String memberCode;

    public MktActivityPOWithBLOBs getActivityPO() {
        return activityPO;
    }

    public void setActivityPO(MktActivityPOWithBLOBs activityPO) {
        this.activityPO = activityPO;
    }

    public MktActivityRedPacketPO getActivityRedPacketPO() {
        return activityRedPacketPO;
    }

    public void setActivityRedPacketPO(MktActivityRedPacketPO activityRedPacketPO) {
        this.activityRedPacketPO = activityRedPacketPO;
    }

    public List<SysStorePo> getStoreList() {
        return storeList;
    }

    public void setStoreList(List<SysStorePo> storeList) {
        this.storeList = storeList;
    }

    public CouponDefinitionPO getCouponDefinitionPO() {
        return couponDefinitionPO;
    }

    public void setCouponDefinitionPO(CouponDefinitionPO couponDefinitionPO) {
        this.couponDefinitionPO = couponDefinitionPO;
    }

    public String getWxNickname() {
        return wxNickname;
    }

    public void setWxNickname(String wxNickname) {
        this.wxNickname = wxNickname;
    }

    public String getWxHeadUrl() {
        return wxHeadUrl;
    }

    public void setWxHeadUrl(String wxHeadUrl) {
        this.wxHeadUrl = wxHeadUrl;
    }

    public Integer getOpenRedEnvel() {
        return openRedEnvel;
    }

    public void setOpenRedEnvel(Integer openRedEnvel) {
        this.openRedEnvel = openRedEnvel;
    }

    public Integer getAssistanceRedEnvel() {
        return assistanceRedEnvel;
    }

    public void setAssistanceRedEnvel(Integer assistanceRedEnvel) {
        this.assistanceRedEnvel = assistanceRedEnvel;
    }

    public Integer getLaunchRedEnvel() {
        return launchRedEnvel;
    }

    public void setLaunchRedEnvel(Integer launchRedEnvel) {
        this.launchRedEnvel = launchRedEnvel;
    }

    public Integer getOrgGrede() {
        return orgGrede;
    }

    public void setOrgGrede(Integer orgGrede) {
        this.orgGrede = orgGrede;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
}
